@@ -42,10 +42,11 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
                 test_loader_name=None, fixture_module=None,
                 response_handlers=None, content_handlers=None,
                 prefix='', require_ssl=False, url=None,
-                inner_fixtures=None, verbose=False):
+                inner_fixtures=None, verbose=False,
+                use_prior_test=True, safe_yaml=True):
     """Read YAML files from a directory to create tests.
 
-    Each YAML file represents an ordered sequence of HTTP requests.
+    Each YAML file represents a list of HTTP requests.
 
     :param path: The directory where yaml files are located.
     :param loader: The TestLoader.
@@ -66,21 +67,26 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
                            individual test request.
     :param verbose: If ``True`` or ``'all'``, make tests verbose by default
                     ``'headers'`` and ``'body'`` are also accepted.
+    :param use_prior_test: If ``True``, uses prior test to create ordered
+                           sequence of tests
+    :param safe_yaml: If ``True``, recognizes only standard YAML tags and not
+                      Python object
     :type inner_fixtures: List of fixtures.Fixture classes.
     :rtype: TestSuite containing multiple TestSuites (one for each YAML file).
     """
 
-    # Exit immediately if we have no host to access, either via a real host
-    # or an intercept.
-    if not bool(host) ^ bool(intercept):
-        raise AssertionError('must specify exactly one of host or intercept')
-
     # If url is being used, reset host, port and prefix.
     if url:
         host, port, prefix, force_ssl = utils.host_info_from_target(url)
         if force_ssl and not require_ssl:
             require_ssl = force_ssl
 
+    # Exit immediately if we have no host to access, either via a real host
+    # or an intercept.
+    if not ((host is not None) ^ bool(intercept)):
+        raise AssertionError(
+            'must specify exactly one of host or url, or intercept')
+
     # If the client has not provided a name to use as our base,
     # create one so that tests are effectively namespaced.
     if test_loader_name is None:
@@ -96,8 +102,8 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
     response_handlers = response_handlers or []
     content_handlers = content_handlers or []
     handler_objects = []
-    for handler in (content_handlers + response_handlers
-                    + handlers.RESPONSE_HANDLERS):
+    for handler in (content_handlers + response_handlers +
+                    handlers.RESPONSE_HANDLERS):
         handler_objects.append(handler())
 
     top_suite = suite.TestSuite()
@@ -108,7 +114,8 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
                 % test_file))
         if intercept:
             host = str(uuid.uuid4())
-        suite_dict = utils.load_yaml(yaml_file=test_file)
+        suite_dict = utils.load_yaml(yaml_file=test_file,
+                                     safe=safe_yaml)
         test_base_name = os.path.splitext(os.path.basename(test_file))[0]
         if all_test_base_name:
             test_base_name = '%s_%s' % (all_test_base_name, test_base_name)
@@ -125,6 +132,12 @@ def build_tests(path, loader, host=None, port=8001, intercept=None,
             else:
                 suite_dict['defaults'] = {'verbose': verbose}
 
+        if not use_prior_test:
+            if 'defaults' in suite_dict:
+                suite_dict['defaults']['use_prior_test'] = use_prior_test
+            else:
+                suite_dict['defaults'] = {'use_prior_test': use_prior_test}
+
         file_suite = suitemaker.test_suite_from_dict(
             loader, test_base_name, suite_dict, path, host, port,
             fixture_module, intercept, prefix=prefix,
@@ -138,7 +151,8 @@ def py_test_generator(test_dir, host=None, port=8001, intercept=None,
                       prefix=None, test_loader_name=None,
                       fixture_module=None, response_handlers=None,
                       content_handlers=None, require_ssl=False, url=None,
-                      metafunc=None):
+                      metafunc=None, use_prior_test=True,
+                      inner_fixtures=None, safe_yaml=True):
     """Generate tests cases for py.test
 
     This uses build_tests to create TestCases and then yields them in
@@ -158,7 +172,8 @@ def py_test_generator(test_dir, host=None, port=8001, intercept=None,
                         response_handlers=response_handlers,
                         content_handlers=content_handlers,
                         prefix=prefix, require_ssl=require_ssl,
-                        url=url)
+                        url=url, use_prior_test=use_prior_test,
+                        safe_yaml=safe_yaml)
 
     test_list = []
     for test in tests:
