@@ -85,6 +85,19 @@ class RunnerTest(unittest.TestCase):
             except SystemExit as err:
                 self.assertFailure(err)
 
+    def test_unsafe_yaml(self):
+        sys.argv = ['gabbi-run', 'http://%s:%s/nan' % (self.host, self.port)]
+
+        sys.argv.append('--unsafe-yaml')
+        sys.argv.append('--')
+        sys.argv.append('gabbi/tests/gabbits_runner/nan.yaml')
+
+        with self.server():
+            try:
+                runner.run()
+            except SystemExit as err:
+                self.assertSuccess(err)
+
     def test_target_url_parsing(self):
         sys.argv = ['gabbi-run', 'http://%s:%s/foo' % (self.host, self.port)]
 
@@ -167,7 +180,7 @@ class RunnerTest(unittest.TestCase):
                 self.assertFailure(err)
 
         sys.argv.insert(3, "-r")
-        sys.argv.insert(4, "gabbi.tests.test_intercept:TestResponseHandler")
+        sys.argv.insert(4, "gabbi.tests.test_intercept:StubResponseHandler")
 
         sys.stdin = StringIO("""
         tests:
@@ -368,7 +381,7 @@ class HTMLResponseHandler(base.ResponseHandler):
     test_key_suffix = 'html'
     test_key_value = {}
 
-    def action(self, test, item, value):
+    def action(self, test, item, value=None):
         doc = test.output
         html = '<{tag}>{content}</{tag}>'.format(tag=item, content=value)
         test.assertTrue(html in doc, "no elements matching '%s'" % html)
